<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam" label-width="auto">
        <el-row :gutter="5">
          <el-col :span="4">
            <el-form-item label="计划年度">
              <!-- <el-input clearable placeholder="请输入计划年度" v-model="querys[0].value" /> -->
              <el-date-picker v-model="querys[0].value" type="year" value-format="yyyy" placeholder="选择年度" style="width: 100%;"/>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="计划名称">
              <el-input clearable placeholder="请输入计划名称" v-model="querys[1].value" />
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="安全业务分类" prop="saftyClass">
              <el-select v-model="querys[2].value" placeholder="请选择安全业务分类" clearable>
                <el-option v-for="item in aqywlbList" :key="item.value" :label="item.name" :value="item.value" />
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="7">
            <el-form-item label="开始时间" prop="planStartDate">
              <el-date-picker v-model="querys[3].value" clearable type="daterange" range-separator="至"
                start-placeholder="开始日期" end-placeholder="结束日期" value-format="yyyy-MM-dd"></el-date-picker>
            </el-form-item>
          </el-col>
          <el-col :span="3">
            <el-button type="primary" icon="el-icon-search" @click="handleSearch">搜索</el-button>
              <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <div class="bbsl-table-content" ref="contentPanel">
      <div class="bbsl-btn-content" ref="btnPanel">
        <el-button icon="el-icon-plus" type="primary" @click="handleAdd">新增</el-button>
        <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
          <el-button slot="reference" :disabled="!multipleSelection.length" icon="el-icon-delete" type="danger"
            style="margin-left: 10px">删除
          </el-button>
        </el-popconfirm>
      </div>
      <el-table border size="mini" v-loading="loading" ref="multipleSelection" :data="tableData"
        :style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
        :header-cell-style="{ 'text-align': 'center' }" @row-dblclick="handleDbClick"
        @selection-change="handleSelectionChange">
        <el-table-column type="selection" width="55"></el-table-column>
        <el-table-column type="index" width="55" label="序号"></el-table-column>
        <el-table-column width="100" sortable prop="planYear" label="计划年度" show-overflow-tooltip></el-table-column>
        <el-table-column min-width="130" prop="planName" label="计划名称" show-overflow-tooltip></el-table-column>
        <el-table-column min-width="100" prop="saftyClassName" label="安全业务分类" show-overflow-tooltip></el-table-column>
        <!-- <el-table-column fixed sortable prop="name" label="主题" show-overflow-tooltip></el-table-column> -->
        <el-table-column sortable width="100" prop="planStartDate" label="开始日期" show-overflow-tooltip></el-table-column>
        <el-table-column sortable width="100" prop="planEndDate" label="结束日期" show-overflow-tooltip></el-table-column>
        <el-table-column prop="planComplet" min-width="120" label="任务完成限时说明" show-overflow-tooltip></el-table-column>
        <el-table-column prop="dutyOrg" label="牵头责任部门" show-overflow-tooltip></el-table-column>
        <el-table-column prop="dutyUser" width="80" label="牵头责任人" show-overflow-tooltip></el-table-column>
        <!-- <el-table-column prop="according" label="任务依据" show-overflow-tooltip></el-table-column> -->
        <el-table-column min-width="120" prop="planDescription" label="计划描述" show-overflow-tooltip></el-table-column>
      </el-table>
      <el-pagination align="right" background class="bbsl-pagination" ref="paginationPanel"
        @size-change="handleSizeChange" @current-change="handleCurrentChange" :current-page="queryParam.pageBean.page"
        :page-sizes="[20, 30, 40, 50]" :page-size="queryParam.pageBean.pageSize"
        layout="total, sizes, prev, pager, next, jumper" :total="total"></el-pagination>
    </div>
    <CmgtSaftyPlanFormDialog ref="formModal"></CmgtSaftyPlanFormDialog>
  </div>
</template>

<script>
import { TableMixin } from '@/mixins/tableMixin'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import dictContracts from '@/components/dict/DictSelectUtils.js'

import CmgtSaftyPlanApi from '@/views/Manage/saftyPlan/api/CmgtSaftyPlanApi'
import CmgtSaftyPlanFormDialog from '@/views/Manage/saftyPlan/components/CmgtSaftyPlanFormDialog'

export default {
  name: 'CmgtSaftyPlanManage',
  components: {
    CmgtSaftyPlanFormDialog
  },
  mixins: [TableMixin],
  data() {
    return {
      url: {
        delete: '/manager/cmgtSaftyPlan/delete'
      },
      querys: [
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'plan_year_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'plan_name_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'safty_class_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'BETWEEN',
          parentGroup: '',
          property: 'plan_start_date_',
          relation: 'AND',
          value: ''
        }
      ],
      StshowFormDias: false,
      fuelTypes: [],
      aqywlbList: []
    }
  },
  created() {
    this.aqywlbList = dictUtils.getDictItemsFromCache('aqywlb')
  },
  mounted() {
  },
  methods: {
    // 重置
    clearQuerys() {
      this.querys[0].value = ''
      this.querys[1].value = ''
      this.querys[2].value = ''
      this.querys[3].value = ''
    },
    // 获取list
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      if (this.querys[2].value) {
        this.queryParam.querys.push(this.querys[2])
      }
      if (this.querys[3].value) {
        this.queryParam.querys.push(this.querys[3])
      }
      CmgtSaftyPlanApi.loadCmgtSaftyPlan(this.queryParam, res => {
        //console.log(res, 'res')
        this.total = res.total
        this.tableData = res.rows
        this.tableData.forEach(item => {
          this.aqywlbList.forEach(val => {
            if (item.saftyClass == val.value) {
              item['saftyClassName'] = val.name
            }
          })
        })

        this.$set(this.tableData)
        this.loading = false
      })
    },
    // 修改
    handleUpdate(row) {
      console.log(row.id)
      this.$refs.formModal.Update(row)
    },
    // 关联设备
    // handleClick(item) {
    //   console.log(item.id)
    //   this.StshowFormDias = true
    // },
    closeStshowForm() {
      this.StshowFormDias = false
    }
  }
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}
</style>
